from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 11 total commands, 2 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	@property
	def bpass(self):
		"""bpass commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_bpass'):
			from .FilterPy_.Bpass import Bpass
			self._bpass = Bpass(self._core, self._base)
		return self._bpass

	@property
	def notch(self):
		"""notch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_notch'):
			from .FilterPy_.Notch import Notch
			self._notch = Notch(self._core, self._base)
		return self._notch

	# noinspection PyTypeChecker
	class LpassStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Filter_Left: enums.LowpassFilterExtended: OFF | F255 | F3K | F3K4 | F4K | F15K Left SPDIF channel
			- Filter_Right: enums.LowpassFilterExtended: OFF | F255 | F3K | F3K4 | F4K | F15K Right SPDIF channel OFF Filter disabled F255, F3K, F3K4, F4K, F15K Cutoff frequency 255 Hz / 3 kHz / 3.4 kHz / 4 kHz / 15 kHz"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Filter_Left', enums.LowpassFilterExtended),
			ArgStruct.scalar_enum('Filter_Right', enums.LowpassFilterExtended)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Filter_Left: enums.LowpassFilterExtended = None
			self.Filter_Right: enums.LowpassFilterExtended = None

	# noinspection PyTypeChecker
	def get_lpass(self) -> LpassStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:LPASs \n
		Snippet: value: LpassStruct = driver.configure.afRf.measurement.spdif.filterPy.get_lpass() \n
		Configures the lowpass filter in the SPDIF input path. \n
			:return: structure: for return value, see the help for LpassStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:LPASs?', self.__class__.LpassStruct())

	def set_lpass(self, value: LpassStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:LPASs \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.set_lpass(value = LpassStruct()) \n
		Configures the lowpass filter in the SPDIF input path. \n
			:param value: see the help for LpassStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:LPASs', value)

	# noinspection PyTypeChecker
	class HpassStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Filter_Left: enums.HighpassFilterExtended: OFF | F6 | F50 | F300 Left SPDIF channel OFF Filter disabled F6, F50, F300 Cutoff frequency 6 Hz / 50 Hz / 300 Hz
			- Filter_Right: enums.HighpassFilterExtended: OFF | F6 | F50 | F300 Right SPDIF channel"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Filter_Left', enums.HighpassFilterExtended),
			ArgStruct.scalar_enum('Filter_Right', enums.HighpassFilterExtended)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Filter_Left: enums.HighpassFilterExtended = None
			self.Filter_Right: enums.HighpassFilterExtended = None

	# noinspection PyTypeChecker
	def get_hpass(self) -> HpassStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:HPASs \n
		Snippet: value: HpassStruct = driver.configure.afRf.measurement.spdif.filterPy.get_hpass() \n
		Configures the highpass filter in the SPDIF input path. \n
			:return: structure: for return value, see the help for HpassStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:HPASs?', self.__class__.HpassStruct())

	def set_hpass(self, value: HpassStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:HPASs \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.set_hpass(value = HpassStruct()) \n
		Configures the highpass filter in the SPDIF input path. \n
			:param value: see the help for HpassStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:HPASs', value)

	# noinspection PyTypeChecker
	class DwidthStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Dwidth_Left: enums.PwrFilterType: WIDE | NARRow Wide or narrow bandwidth, left channel
			- Drelative_Left: enums.Relative: RELative | CONStant Proportional to reference frequency or constant, left channel
			- Dwidth_Right: enums.PwrFilterType: WIDE | NARRow Wide or narrow bandwidth, right channel
			- Drelative_Right: enums.Relative: RELative | CONStant Proportional to reference frequency or constant, right channel"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Dwidth_Left', enums.PwrFilterType),
			ArgStruct.scalar_enum('Drelative_Left', enums.Relative),
			ArgStruct.scalar_enum('Dwidth_Right', enums.PwrFilterType),
			ArgStruct.scalar_enum('Drelative_Right', enums.Relative)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Dwidth_Left: enums.PwrFilterType = None
			self.Drelative_Left: enums.Relative = None
			self.Dwidth_Right: enums.PwrFilterType = None
			self.Drelative_Right: enums.Relative = None

	# noinspection PyTypeChecker
	def get_dwidth(self) -> DwidthStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:DWIDth \n
		Snippet: value: DwidthStruct = driver.configure.afRf.measurement.spdif.filterPy.get_dwidth() \n
		Configures the bandwidth of the distortion filter in the SPDIF input path. \n
			:return: structure: for return value, see the help for DwidthStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:DWIDth?', self.__class__.DwidthStruct())

	def set_dwidth(self, value: DwidthStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:DWIDth \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.set_dwidth(value = DwidthStruct()) \n
		Configures the bandwidth of the distortion filter in the SPDIF input path. \n
			:param value: see the help for DwidthStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:DWIDth', value)

	# noinspection PyTypeChecker
	class WeightingStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Filter_Left: enums.WeightingFilter: OFF | AWEighting | CCITt | CMESsage Left SPDIF channel OFF Filter disabled AWEighting A-weighting filter CCITt CCITT weighting filter CMESsage C-message weighting filter
			- Filter_Right: enums.WeightingFilter: OFF | AWEighting | CCITt | CMESsage Right SPDIF channel"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Filter_Left', enums.WeightingFilter),
			ArgStruct.scalar_enum('Filter_Right', enums.WeightingFilter)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Filter_Left: enums.WeightingFilter = None
			self.Filter_Right: enums.WeightingFilter = None

	# noinspection PyTypeChecker
	def get_weighting(self) -> WeightingStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:WEIGhting \n
		Snippet: value: WeightingStruct = driver.configure.afRf.measurement.spdif.filterPy.get_weighting() \n
		Configures the weighting filter in the SPDIF input path. \n
			:return: structure: for return value, see the help for WeightingStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:WEIGhting?', self.__class__.WeightingStruct())

	def set_weighting(self, value: WeightingStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:WEIGhting \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.set_weighting(value = WeightingStruct()) \n
		Configures the weighting filter in the SPDIF input path. \n
			:param value: see the help for WeightingStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:WEIGhting', value)

	# noinspection PyTypeChecker
	class DfrequencyStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Distor_Freq_Left: float: Frequency for left SPDIF channel Unit: Hz
			- Distor_Freq_Right: float: Frequency for right SPDIF channel Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Distor_Freq_Left'),
			ArgStruct.scalar_float('Distor_Freq_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Distor_Freq_Left: float = None
			self.Distor_Freq_Right: float = None

	def get_dfrequency(self) -> DfrequencyStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:DFRequency \n
		Snippet: value: DfrequencyStruct = driver.configure.afRf.measurement.spdif.filterPy.get_dfrequency() \n
		Configures the reference frequency for single-tone measurements via the SPDIF input path. \n
			:return: structure: for return value, see the help for DfrequencyStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:DFRequency?', self.__class__.DfrequencyStruct())

	def set_dfrequency(self, value: DfrequencyStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:DFRequency \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.set_dfrequency(value = DfrequencyStruct()) \n
		Configures the reference frequency for single-tone measurements via the SPDIF input path. \n
			:param value: see the help for DfrequencyStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:DFRequency', value)

	# noinspection PyTypeChecker
	class RobustAutoStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Automatic_Mode_Left: bool: OFF | ON
			- Automatic_Mode_Right: bool: OFF | ON"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Automatic_Mode_Left'),
			ArgStruct.scalar_bool('Automatic_Mode_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Automatic_Mode_Left: bool = None
			self.Automatic_Mode_Right: bool = None

	def get_robust_auto(self) -> RobustAutoStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:ROBustauto \n
		Snippet: value: RobustAutoStruct = driver.configure.afRf.measurement.spdif.filterPy.get_robust_auto() \n
		Enables or disables robust automatic mode for distortion signal filtering in the SPDIF input path. \n
			:return: structure: for return value, see the help for RobustAutoStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:ROBustauto?', self.__class__.RobustAutoStruct())

	def set_robust_auto(self, value: RobustAutoStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:ROBustauto \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.set_robust_auto(value = RobustAutoStruct()) \n
		Enables or disables robust automatic mode for distortion signal filtering in the SPDIF input path. \n
			:param value: see the help for RobustAutoStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:ROBustauto', value)

	def clone(self) -> 'FilterPy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cenable:
	"""Cenable commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cenable", core, parent)

	# noinspection PyTypeChecker
	def get_state(self) -> enums.UserRole:
		"""SCPI: SYSTem:BASE:PASSword[:CENable]:STATe \n
		Snippet: value: enums.UserRole = driver.system.base.password.cenable.get_state() \n
		No command help available \n
			:return: user_mode: No help available
		"""
		response = self._core.io.query_str('SYSTem:BASE:PASSword:CENable:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.UserRole)

	def set(self, user_mode: enums.UserRole, password: str) -> None:
		"""SCPI: SYSTem:BASE:PASSword[:CENable] \n
		Snippet: driver.system.base.password.cenable.set(user_mode = enums.UserRole.ADMin, password = '1') \n
		No command help available \n
			:param user_mode: No help available
			:param password: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('user_mode', user_mode, DataType.Enum), ArgSingle('password', password, DataType.String))
		self._core.io.write(f'SYSTem:BASE:PASSword:CENable {param}'.rstrip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Speak:
	"""Speak commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("speak", core, parent)

	# noinspection PyTypeChecker
	class FetchStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Xvalue: float: No parameter help available
			- Yvalue: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Xvalue'),
			ArgStruct.scalar_float('Yvalue')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Xvalue: float = None
			self.Yvalue: float = None

	def fetch(self, detector: enums.Detector, statistic: enums.Statistic) -> FetchStruct:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:SPECtrum:REFMarker:SPEak \n
		Snippet: value: FetchStruct = driver.gprfMeasurement.spectrum.referenceMarker.speak.fetch(detector = enums.Detector.AUTopeak, statistic = enums.Statistic.AVERage) \n
		No command help available \n
			:param detector: No help available
			:param statistic: No help available
			:return: structure: for return value, see the help for FetchStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('detector', detector, DataType.Enum), ArgSingle('statistic', statistic, DataType.Enum))
		return self._core.io.query_struct(f'FETCh:GPRF:MEASurement<Instance>:SPECtrum:REFMarker:SPEak? {param}'.rstrip(), self.__class__.FetchStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, enable: bool, audioOutput=repcap.AudioOutput.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:AOUT<nr>:ENABle \n
		Snippet: driver.source.afRf.generator.audioOutput.enable.set(enable = False, audioOutput = repcap.AudioOutput.Default) \n
		Enables or disables an AF OUT connector. \n
			:param enable: OFF | ON
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')"""
		param = Conversions.bool_to_str(enable)
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:AOUT{audioOutput_cmd_val}:ENABle {param}')

	def get(self, audioOutput=repcap.AudioOutput.Default) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:AOUT<nr>:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.audioOutput.enable.get(audioOutput = repcap.AudioOutput.Default) \n
		Enables or disables an AF OUT connector. \n
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')
			:return: enable: OFF | ON"""
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:AOUT{audioOutput_cmd_val}:ENABle?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfSettings:
	"""RfSettings commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfSettings", core, parent)

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.XrtInputConnector:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:CONNector \n
		Snippet: value: enums.XrtInputConnector = driver.configure.vse.measurement.xrt.rfSettings.get_connector() \n
		No command help available \n
			:return: input_connector: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.XrtInputConnector)

	def set_connector(self, input_connector: enums.XrtInputConnector) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:CONNector \n
		Snippet: driver.configure.vse.measurement.xrt.rfSettings.set_connector(input_connector = enums.XrtInputConnector.RF1) \n
		No command help available \n
			:param input_connector: No help available
		"""
		param = Conversions.enum_scalar_to_str(input_connector, enums.XrtInputConnector)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:CONNector {param}')

	def get_frequency(self) -> float:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:FREQuency \n
		Snippet: value: float = driver.configure.vse.measurement.xrt.rfSettings.get_frequency() \n
		No command help available \n
			:return: frequency: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:FREQuency \n
		Snippet: driver.configure.vse.measurement.xrt.rfSettings.set_frequency(frequency = 1.0) \n
		No command help available \n
			:param frequency: No help available
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:FREQuency {param}')

	def get_envelope_power(self) -> float:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:ENPower \n
		Snippet: value: float = driver.configure.vse.measurement.xrt.rfSettings.get_envelope_power() \n
		No command help available \n
			:return: exp_nominal_power: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:ENPower?')
		return Conversions.str_to_float(response)

	def set_envelope_power(self, exp_nominal_power: float) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:ENPower \n
		Snippet: driver.configure.vse.measurement.xrt.rfSettings.set_envelope_power(exp_nominal_power = 1.0) \n
		No command help available \n
			:param exp_nominal_power: No help available
		"""
		param = Conversions.decimal_value_to_str(exp_nominal_power)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:XRT:RFSettings:ENPower {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType
from .....Internal.Utilities import trim_str_response
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Reliability:
	"""Reliability commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("reliability", core, parent)

	def get(self, details: str = None) -> str:
		"""SCPI: SOURce:XRT:GENerator<Instance>:RELiability \n
		Snippet: value: str = driver.source.xrt.generator.reliability.get(details = '1') \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:param details: No help available
			:return: reliability_msg: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('details', details, DataType.String, True))
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'SOURce:XRT:GENerator<Instance>:RELiability? {param}'.rstrip(), suppressed)
		return trim_str_response(response)

	# noinspection PyTypeChecker
	class AllStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Reliability: int: No parameter help available
			- Reliability_Msg: str: No parameter help available
			- Reliability_Add_Info: str: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_str('Reliability_Msg'),
			ArgStruct.scalar_str('Reliability_Add_Info')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Reliability_Msg: str = None
			self.Reliability_Add_Info: str = None

	def get_all(self) -> AllStruct:
		"""SCPI: SOURce:XRT:GENerator<Instance>:RELiability:ALL \n
		Snippet: value: AllStruct = driver.source.xrt.generator.reliability.get_all() \n
		No command help available \n
			:return: structure: for return value, see the help for AllStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:XRT:GENerator<Instance>:RELiability:ALL?', self.__class__.AllStruct())



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GprfMeasurement:
	"""GprfMeasurement commands group definition. 198 total commands, 7 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gprfMeasurement", core, parent)

	@property
	def spectrum(self):
		"""spectrum commands group. 11 Sub-classes, 3 commands."""
		if not hasattr(self, '_spectrum'):
			from .GprfMeasurement_.Spectrum import Spectrum
			self._spectrum = Spectrum(self._core, self._base)
		return self._spectrum

	@property
	def extPwrSensor(self):
		"""extPwrSensor commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_extPwrSensor'):
			from .GprfMeasurement_.ExtPwrSensor import ExtPwrSensor
			self._extPwrSensor = ExtPwrSensor(self._core, self._base)
		return self._extPwrSensor

	@property
	def nrt(self):
		"""nrt commands group. 3 Sub-classes, 4 commands."""
		if not hasattr(self, '_nrt'):
			from .GprfMeasurement_.Nrt import Nrt
			self._nrt = Nrt(self._core, self._base)
		return self._nrt

	@property
	def power(self):
		"""power commands group. 8 Sub-classes, 3 commands."""
		if not hasattr(self, '_power'):
			from .GprfMeasurement_.Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def fftSpecAn(self):
		"""fftSpecAn commands group. 7 Sub-classes, 3 commands."""
		if not hasattr(self, '_fftSpecAn'):
			from .GprfMeasurement_.FftSpecAn import FftSpecAn
			self._fftSpecAn = FftSpecAn(self._core, self._base)
		return self._fftSpecAn

	@property
	def acp(self):
		"""acp commands group. 4 Sub-classes, 3 commands."""
		if not hasattr(self, '_acp'):
			from .GprfMeasurement_.Acp import Acp
			self._acp = Acp(self._core, self._base)
		return self._acp

	@property
	def iqRecorder(self):
		"""iqRecorder commands group. 5 Sub-classes, 5 commands."""
		if not hasattr(self, '_iqRecorder'):
			from .GprfMeasurement_.IqRecorder import IqRecorder
			self._iqRecorder = IqRecorder(self._core, self._base)
		return self._iqRecorder

	def clone(self) -> 'GprfMeasurement':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = GprfMeasurement(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Voip:
	"""Voip commands group definition. 41 total commands, 7 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("voip", core, parent)

	@property
	def level(self):
		"""level commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .Voip_.Level import Level
			self._level = Level(self._core, self._base)
		return self._level

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .Voip_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def uri(self):
		"""uri commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_uri'):
			from .Voip_.Uri import Uri
			self._uri = Uri(self._core, self._base)
		return self._uri

	@property
	def sip(self):
		"""sip commands group. 0 Sub-classes, 6 commands."""
		if not hasattr(self, '_sip'):
			from .Voip_.Sip import Sip
			self._sip = Sip(self._core, self._base)
		return self._sip

	@property
	def squelch(self):
		"""squelch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_squelch'):
			from .Voip_.Squelch import Squelch
			self._squelch = Squelch(self._core, self._base)
		return self._squelch

	@property
	def rssi(self):
		"""rssi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rssi'):
			from .Voip_.Rssi import Rssi
			self._rssi = Rssi(self._core, self._base)
		return self._rssi

	@property
	def filterPy(self):
		"""filterPy commands group. 2 Sub-classes, 6 commands."""
		if not hasattr(self, '_filterPy'):
			from .Voip_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	# noinspection PyTypeChecker
	def get_gcoupling(self) -> enums.GeneratorCouplingVoIp:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:GCOupling \n
		Snippet: value: enums.GeneratorCouplingVoIp = driver.configure.afRf.measurement.voip.get_gcoupling() \n
		Couples the audio output of the VoIP input path to an internal signal generator. \n
			:return: coupling: OFF | GEN3 | GEN4 OFF No coupling GEN3 Coupled to audio generator 3 GEN4 Coupled to audio generator 4
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:GCOupling?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorCouplingVoIp)

	def set_gcoupling(self, coupling: enums.GeneratorCouplingVoIp) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:GCOupling \n
		Snippet: driver.configure.afRf.measurement.voip.set_gcoupling(coupling = enums.GeneratorCouplingVoIp.GEN3) \n
		Couples the audio output of the VoIP input path to an internal signal generator. \n
			:param coupling: OFF | GEN3 | GEN4 OFF No coupling GEN3 Coupled to audio generator 3 GEN4 Coupled to audio generator 4
		"""
		param = Conversions.enum_scalar_to_str(coupling, enums.GeneratorCouplingVoIp)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:GCOupling {param}')

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:ENABle \n
		Snippet: value: bool = driver.configure.afRf.measurement.voip.get_enable() \n
		Enables or disables the audio signal output of the VoIP input path. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:ENABle \n
		Snippet: driver.configure.afRf.measurement.voip.set_enable(enable = False) \n
		Enables or disables the audio signal output of the VoIP input path. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:ENABle {param}')

	# noinspection PyTypeChecker
	def get_pcodec(self) -> enums.VoIpCodec:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:PCODec \n
		Snippet: value: enums.VoIpCodec = driver.configure.afRf.measurement.voip.get_pcodec() \n
		Queries the type of the pulse code modulation (PCM) codec. \n
			:return: pcodec: ALAW | ULAW A-law codec or µ-law codec
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:PCODec?')
		return Conversions.str_to_scalar_enum(response, enums.VoIpCodec)

	def get_fid(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FID \n
		Snippet: value: float = driver.configure.afRf.measurement.voip.get_fid() \n
		Specifies the frequency ID (FID) configured at the DUT.
			INTRO_CMD_HELP: Allowed values are, with n = 0 to 39995: \n
			- 0.100 + n * 0.025
			- 0.105 + n * 0.025
			- 0.110 + n * 0.025
			- 0.115 + n * 0.025
		Resulting in: 0.100, 0.105, 0.110, 0.115, 0.125, 0.130, 0.135, 0.140, ..., 999.975, 999.980, 999.985, 999.990 \n
			:return: frequency_id: Frequency ID Not allowed values are rounded to the closest allowed value. Range: 0.1 to 999.99
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FID?')
		return Conversions.str_to_float(response)

	def set_fid(self, frequency_id: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FID \n
		Snippet: driver.configure.afRf.measurement.voip.set_fid(frequency_id = 1.0) \n
		Specifies the frequency ID (FID) configured at the DUT.
			INTRO_CMD_HELP: Allowed values are, with n = 0 to 39995: \n
			- 0.100 + n * 0.025
			- 0.105 + n * 0.025
			- 0.110 + n * 0.025
			- 0.115 + n * 0.025
		Resulting in: 0.100, 0.105, 0.110, 0.115, 0.125, 0.130, 0.135, 0.140, ..., 999.975, 999.980, 999.985, 999.990 \n
			:param frequency_id: Frequency ID Not allowed values are rounded to the closest allowed value. Range: 0.1 to 999.99
		"""
		param = Conversions.decimal_value_to_str(frequency_id)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FID {param}')

	def clone(self) -> 'Voip':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Voip(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rbw:
	"""Rbw commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rbw", core, parent)

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.RbwFilterType:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:TYPE \n
		Snippet: value: enums.RbwFilterType = driver.configure.gprfMeasurement.spectrum.zeroSpan.rbw.get_type_py() \n
		Selects the resolution filter type for the zero span mode. \n
			:return: rbw_type: GAUSs | BANDpass GAUSs Gaussian filter with configurable bandwidth BANDpass Bandpass filter with 40 MHz bandwidth
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.RbwFilterType)

	def set_type_py(self, rbw_type: enums.RbwFilterType) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:TYPE \n
		Snippet: driver.configure.gprfMeasurement.spectrum.zeroSpan.rbw.set_type_py(rbw_type = enums.RbwFilterType.BANDpass) \n
		Selects the resolution filter type for the zero span mode. \n
			:param rbw_type: GAUSs | BANDpass GAUSs Gaussian filter with configurable bandwidth BANDpass Bandpass filter with 40 MHz bandwidth
		"""
		param = Conversions.enum_scalar_to_str(rbw_type, enums.RbwFilterType)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:TYPE {param}')

	def get_bandpass(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:BANDpass \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.zeroSpan.rbw.get_bandpass() \n
		No command help available \n
			:return: rbw_bandpass: No help available
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:BANDpass?')
		return Conversions.str_to_float(response)

	def set_bandpass(self, rbw_bandpass: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:BANDpass \n
		Snippet: driver.configure.gprfMeasurement.spectrum.zeroSpan.rbw.set_bandpass(rbw_bandpass = 1.0) \n
		No command help available \n
			:param rbw_bandpass: No help available
		"""
		param = Conversions.decimal_value_to_str(rbw_bandpass)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:BANDpass {param}')

	def get_gauss(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:GAUSs \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.zeroSpan.rbw.get_gauss() \n
		Selects the bandwidth of the Gaussian resolution filter for the zero span mode. To use this filter, configure also method
		RsCma.Configure.GprfMeasurement.Spectrum.ZeroSpan.Rbw.typePy. \n
			:return: rbw: You can enter values between 100 Hz and 10 MHz. The setting is rounded to the closest of the following values: 100 / 200 / 300 / 500 Hz 1 / 2 / 3 / 5 / 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 kHz 1 / 2 / 3 / 5 / 10 MHz Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:GAUSs?')
		return Conversions.str_to_float(response)

	def set_gauss(self, rbw: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:GAUSs \n
		Snippet: driver.configure.gprfMeasurement.spectrum.zeroSpan.rbw.set_gauss(rbw = 1.0) \n
		Selects the bandwidth of the Gaussian resolution filter for the zero span mode. To use this filter, configure also method
		RsCma.Configure.GprfMeasurement.Spectrum.ZeroSpan.Rbw.typePy. \n
			:param rbw: You can enter values between 100 Hz and 10 MHz. The setting is rounded to the closest of the following values: 100 / 200 / 300 / 500 Hz 1 / 2 / 3 / 5 / 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 kHz 1 / 2 / 3 / 5 / 10 MHz Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(rbw)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:RBW:GAUSs {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spectrum:
	"""Spectrum commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spectrum", core, parent)

	def get_tgenerator(self) -> bool:
		"""SCPI: CALibration:GPRF:MEASurement<Instance>:SPECtrum:TGENerator \n
		Snippet: value: bool = driver.calibration.gprfMeasurement.spectrum.get_tgenerator() \n
		Starts or aborts the calibration for a tracking generator setup. \n
			:return: calibrate: OFF | ON ON Setting ON starts the calibration. Return value ON indicates an ongoing calibration. OFF Setting OFF aborts an ongoing calibration. Return value OFF indicates that there is no ongoing calibration.
		"""
		response = self._core.io.query_str('CALibration:GPRF:MEASurement<Instance>:SPECtrum:TGENerator?')
		return Conversions.str_to_bool(response)

	def set_tgenerator(self, calibrate: bool) -> None:
		"""SCPI: CALibration:GPRF:MEASurement<Instance>:SPECtrum:TGENerator \n
		Snippet: driver.calibration.gprfMeasurement.spectrum.set_tgenerator(calibrate = False) \n
		Starts or aborts the calibration for a tracking generator setup. \n
			:param calibrate: OFF | ON ON Setting ON starts the calibration. Return value ON indicates an ongoing calibration. OFF Setting OFF aborts an ongoing calibration. Return value OFF indicates that there is no ongoing calibration.
		"""
		param = Conversions.bool_to_str(calibrate)
		self._core.io.write(f'CALibration:GPRF:MEASurement<Instance>:SPECtrum:TGENerator {param}')



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Battery:
	"""Battery commands group definition. 5 total commands, 1 Sub-groups, 4 group commands
	Repeated Capability: Battery, default value after init: Battery.Ix1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("battery", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_battery_get', 'repcap_battery_set', repcap.Battery.Ix1)

	def repcap_battery_set(self, enum_value: repcap.Battery) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Battery.Default
		Default value after init: Battery.Ix1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_battery_get(self) -> repcap.Battery:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def info(self):
		"""info commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_info'):
			from .Battery_.Info import Info
			self._info = Info(self._core, self._base)
		return self._info

	def get_available(self) -> bool:
		"""SCPI: SENSe:BASE:BATTery:AVAilable \n
		Snippet: value: bool = driver.sense.base.battery.get_available() \n
		Queries if at least one battery is inserted. \n
			:return: batt_available: OFF | ON OFF: No battery inserted ON: One or two batteries inserted
		"""
		response = self._core.io.query_str('SENSe:BASE:BATTery:AVAilable?')
		return Conversions.str_to_bool(response)

	def get_capacity(self) -> float:
		"""SCPI: SENSe:BASE:BATTery:CAPacity \n
		Snippet: value: float = driver.sense.base.battery.get_capacity() \n
		Queries the total capacity (sum of available batteries) . \n
			:return: batt_capacity: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SENSe:BASE:BATTery:CAPacity?')
		return Conversions.str_to_float(response)

	def get_ttd(self) -> int:
		"""SCPI: SENSe:BASE:BATTery:TTD \n
		Snippet: value: int = driver.sense.base.battery.get_ttd() \n
		Queries the estimated total remaining runtime for the sum of all available batteries. The value is calculated from the
		total capacity and the current discharge rate of the used battery. \n
			:return: ttd: Time until discharged Unit: s
		"""
		response = self._core.io.query_str('SENSe:BASE:BATTery:TTD?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	def get_usage(self) -> List[enums.BatteryUsage]:
		"""SCPI: SENSe:BASE:BATTery:USAGe \n
		Snippet: value: List[enums.BatteryUsage] = driver.sense.base.battery.get_usage() \n
		Queries the state of both slots of the battery compartment. Two values are returned: <BattUsage>slot 1, <BattUsage>slot 2 \n
			:return: batt_usage: NAV | REMovable | USED NAV Slot empty REMovable Battery inserted but currently not used - can be removed USED Battery currently used - do not remove it
		"""
		response = self._core.io.query_str('SENSe:BASE:BATTery:USAGe?')
		return Conversions.str_to_list_enum(response, enums.BatteryUsage)

	def clone(self) -> 'Battery':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Battery(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Lte:
	"""Lte commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("lte", core, parent)

	# noinspection PyTypeChecker
	def get_cbwidth(self) -> enums.LteChannelBandwidth:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:LTE:CBWidth \n
		Snippet: value: enums.LteChannelBandwidth = driver.configure.vse.measurement.iqRecorder.lte.get_cbwidth() \n
		No command help available \n
			:return: channel_bandwidth: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:IQRecorder:LTE:CBWidth?')
		return Conversions.str_to_scalar_enum(response, enums.LteChannelBandwidth)

	def set_cbwidth(self, channel_bandwidth: enums.LteChannelBandwidth) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:LTE:CBWidth \n
		Snippet: driver.configure.vse.measurement.iqRecorder.lte.set_cbwidth(channel_bandwidth = enums.LteChannelBandwidth.F10M) \n
		No command help available \n
			:param channel_bandwidth: No help available
		"""
		param = Conversions.enum_scalar_to_str(channel_bandwidth, enums.LteChannelBandwidth)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:LTE:CBWidth {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Deviation:
	"""Deviation commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("deviation", core, parent)

	# noinspection PyTypeChecker
	class CalculateStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Thd_Percent: enums.ResultStatus: Total harmonic distortion in percent Unit: %
			- Thd: float: Total harmonic distortion in dB Unit: dB
			- Thd_Plus_Noise: float: Total harmonic distortion and noise Unit: %
			- Sinad: enums.ResultStatus: Signal to noise and distortion Unit: dB
			- Snr: enums.ResultStatus: Signal-to-noise ratio S/N Unit: dB
			- Snr_Plus_Noise: float: (S+N) /N Unit: dB
			- Snr_Plus_Noinse_Plus_Dist: float: (S+N+D) /N Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_enum('Thd_Percent', enums.ResultStatus),
			ArgStruct.scalar_float('Thd'),
			ArgStruct.scalar_float('Thd_Plus_Noise'),
			ArgStruct.scalar_enum('Sinad', enums.ResultStatus),
			ArgStruct.scalar_enum('Snr', enums.ResultStatus),
			ArgStruct.scalar_float('Snr_Plus_Noise'),
			ArgStruct.scalar_float('Snr_Plus_Noinse_Plus_Dist')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Thd_Percent: enums.ResultStatus = None
			self.Thd: float = None
			self.Thd_Plus_Noise: float = None
			self.Sinad: enums.ResultStatus = None
			self.Snr: enums.ResultStatus = None
			self.Snr_Plus_Noise: float = None
			self.Snr_Plus_Noinse_Plus_Dist: float = None

	def calculate(self, audioInput=repcap.AudioInput.Default) -> CalculateStruct:
		"""SCPI: CALCulate:AFRF:MEASurement<Instance>:MEValuation:SQUality:AIN<Nr>:DEViation \n
		Snippet: value: CalculateStruct = driver.afRf.measurement.multiEval.signalQuality.audioInput.deviation.calculate(audioInput = repcap.AudioInput.Default) \n
		Queries the signal quality results measured for an AF input path. CALCulate commands return error indicators instead of
		measurement values. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for CalculateStruct structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'CALCulate:AFRF:MEASurement<Instance>:MEValuation:SQUality:AIN{audioInput_cmd_val}:DEViation?', self.__class__.CalculateStruct())

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Thd_Percent: float: Total harmonic distortion in percent Unit: %
			- Thd: float: Total harmonic distortion in dB Unit: dB
			- Thd_Plus_Noise: float: Total harmonic distortion and noise Unit: %
			- Sinad: float: Signal to noise and distortion Unit: dB
			- Snr: float: Signal-to-noise ratio S/N Unit: dB
			- Snr_Plus_Noise: float: (S+N) /N Unit: dB
			- Snr_Plus_Noinse_Plus_Dist: float: (S+N+D) /N Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Thd_Percent'),
			ArgStruct.scalar_float('Thd'),
			ArgStruct.scalar_float('Thd_Plus_Noise'),
			ArgStruct.scalar_float('Sinad'),
			ArgStruct.scalar_float('Snr'),
			ArgStruct.scalar_float('Snr_Plus_Noise'),
			ArgStruct.scalar_float('Snr_Plus_Noinse_Plus_Dist')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Thd_Percent: float = None
			self.Thd: float = None
			self.Thd_Plus_Noise: float = None
			self.Sinad: float = None
			self.Snr: float = None
			self.Snr_Plus_Noise: float = None
			self.Snr_Plus_Noinse_Plus_Dist: float = None

	def fetch(self, audioInput=repcap.AudioInput.Default) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:SQUality:AIN<Nr>:DEViation \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.signalQuality.audioInput.deviation.fetch(audioInput = repcap.AudioInput.Default) \n
		Queries the signal quality results measured for an AF input path. CALCulate commands return error indicators instead of
		measurement values. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for ResultData structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:SQUality:AIN{audioInput_cmd_val}:DEViation?', self.__class__.ResultData())

	def read(self, audioInput=repcap.AudioInput.Default) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:SQUality:AIN<Nr>:DEViation \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.signalQuality.audioInput.deviation.read(audioInput = repcap.AudioInput.Default) \n
		Queries the signal quality results measured for an AF input path. CALCulate commands return error indicators instead of
		measurement values. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for ResultData structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:SQUality:AIN{audioInput_cmd_val}:DEViation?', self.__class__.ResultData())



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions
from ..Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Display:
	"""Display commands group definition. 8 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("display", core, parent)

	@property
	def afRf(self):
		"""afRf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_afRf'):
			from .Display_.AfRf import AfRf
			self._afRf = AfRf(self._core, self._base)
		return self._afRf

	@property
	def gprfMeasurement(self):
		"""gprfMeasurement commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_gprfMeasurement'):
			from .Display_.GprfMeasurement import GprfMeasurement
			self._gprfMeasurement = GprfMeasurement(self._core, self._base)
		return self._gprfMeasurement

	@property
	def window(self):
		"""window commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_window'):
			from .Display_.Window import Window
			self._window = Window(self._core, self._base)
		return self._window

	def get_format_py(self) -> str:
		"""SCPI: DISPlay:FORMat \n
		Snippet: value: str = driver.display.get_format_py() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('DISPlay:FORMat?')
		return trim_str_response(response)

	def set_format_py(self, arg_0: str) -> None:
		"""SCPI: DISPlay:FORMat \n
		Snippet: driver.display.set_format_py(arg_0 = r1) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.value_to_str(arg_0)
		self._core.io.write(f'DISPlay:FORMat {param}')

	def clone(self) -> 'Display':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Display(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Select:
	"""Select commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("select", core, parent)

	def set(self, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<1-n>]:SELect \n
		Snippet: driver.display.window.select.set(window = repcap.Window.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Win1 (settable in the interface 'Window')"""
		window_cmd_val = self._base.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SELect')

	def set_with_opc(self, window=repcap.Window.Default) -> None:
		window_cmd_val = self._base.get_repcap_cmd_value(window, repcap.Window)
		"""SCPI: DISPlay[:WINDow<1-n>]:SELect \n
		Snippet: driver.display.window.select.set_with_opc(window = repcap.Window.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Win1 (settable in the interface 'Window')"""
		self._core.io.write_with_opc(f'DISPlay:WINDow{window_cmd_val}:SELect')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ecircuitry:
	"""Ecircuitry commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ecircuitry", core, parent)

	def set(self, circuitry_state: enums.CircuitryState, audioOutput=repcap.AudioOutput.Default) -> None:
		"""SCPI: CONFigure:BASE:AOUT<nr>:ECIRcuitry \n
		Snippet: driver.configure.base.audioOutput.ecircuitry.set(circuitry_state = enums.CircuitryState.ACTive, audioOutput = repcap.AudioOutput.Default) \n
		Selects the set of AF impedance settings to be used. \n
			:param circuitry_state: PASSive | ACTive ACTive: settings for R&S CMA-Z600A (ZBOX commands) PASSive: settings for other equipment (other commands)
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')"""
		param = Conversions.enum_scalar_to_str(circuitry_state, enums.CircuitryState)
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		self._core.io.write(f'CONFigure:BASE:AOUT{audioOutput_cmd_val}:ECIRcuitry {param}')

	# noinspection PyTypeChecker
	def get(self, audioOutput=repcap.AudioOutput.Default) -> enums.CircuitryState:
		"""SCPI: CONFigure:BASE:AOUT<nr>:ECIRcuitry \n
		Snippet: value: enums.CircuitryState = driver.configure.base.audioOutput.ecircuitry.get(audioOutput = repcap.AudioOutput.Default) \n
		Selects the set of AF impedance settings to be used. \n
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')
			:return: circuitry_state: PASSive | ACTive ACTive: settings for R&S CMA-Z600A (ZBOX commands) PASSive: settings for other equipment (other commands)"""
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		response = self._core.io.query_str(f'CONFigure:BASE:AOUT{audioOutput_cmd_val}:ECIRcuitry?')
		return Conversions.str_to_scalar_enum(response, enums.CircuitryState)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 11 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	@property
	def lpass(self):
		"""lpass commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lpass'):
			from .FilterPy_.Lpass import Lpass
			self._lpass = Lpass(self._core, self._base)
		return self._lpass

	@property
	def hpass(self):
		"""hpass commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hpass'):
			from .FilterPy_.Hpass import Hpass
			self._hpass = Hpass(self._core, self._base)
		return self._hpass

	@property
	def dwidth(self):
		"""dwidth commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dwidth'):
			from .FilterPy_.Dwidth import Dwidth
			self._dwidth = Dwidth(self._core, self._base)
		return self._dwidth

	@property
	def bpass(self):
		"""bpass commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_bpass'):
			from .FilterPy_.Bpass import Bpass
			self._bpass = Bpass(self._core, self._base)
		return self._bpass

	@property
	def weighting(self):
		"""weighting commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_weighting'):
			from .FilterPy_.Weighting import Weighting
			self._weighting = Weighting(self._core, self._base)
		return self._weighting

	@property
	def dfrequency(self):
		"""dfrequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dfrequency'):
			from .FilterPy_.Dfrequency import Dfrequency
			self._dfrequency = Dfrequency(self._core, self._base)
		return self._dfrequency

	@property
	def robustAuto(self):
		"""robustAuto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_robustAuto'):
			from .FilterPy_.RobustAuto import RobustAuto
			self._robustAuto = RobustAuto(self._core, self._base)
		return self._robustAuto

	@property
	def notch(self):
		"""notch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_notch'):
			from .FilterPy_.Notch import Notch
			self._notch = Notch(self._core, self._base)
		return self._notch

	def clone(self) -> 'FilterPy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Measurement:
	"""Measurement commands group definition. 85 total commands, 19 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("measurement", core, parent)

	@property
	def dmr(self):
		"""dmr commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmr'):
			from .Measurement_.Dmr import Dmr
			self._dmr = Dmr(self._core, self._base)
		return self._dmr

	@property
	def nxdn(self):
		"""nxdn commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_nxdn'):
			from .Measurement_.Nxdn import Nxdn
			self._nxdn = Nxdn(self._core, self._base)
		return self._nxdn

	@property
	def tetra(self):
		"""tetra commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tetra'):
			from .Measurement_.Tetra import Tetra
			self._tetra = Tetra(self._core, self._base)
		return self._tetra

	@property
	def dpmr(self):
		"""dpmr commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_dpmr'):
			from .Measurement_.Dpmr import Dpmr
			self._dpmr = Dpmr(self._core, self._base)
		return self._dpmr

	@property
	def lte(self):
		"""lte commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_lte'):
			from .Measurement_.Lte import Lte
			self._lte = Lte(self._core, self._base)
		return self._lte

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Measurement_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def cons(self):
		"""cons commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cons'):
			from .Measurement_.Cons import Cons
			self._cons = Cons(self._core, self._base)
		return self._cons

	@property
	def ediagram(self):
		"""ediagram commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ediagram'):
			from .Measurement_.Ediagram import Ediagram
			self._ediagram = Ediagram(self._core, self._base)
		return self._ediagram

	@property
	def powerVsTime(self):
		"""powerVsTime commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_powerVsTime'):
			from .Measurement_.PowerVsTime import PowerVsTime
			self._powerVsTime = PowerVsTime(self._core, self._base)
		return self._powerVsTime

	@property
	def perror(self):
		"""perror commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_perror'):
			from .Measurement_.Perror import Perror
			self._perror = Perror(self._core, self._base)
		return self._perror

	@property
	def evm(self):
		"""evm commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_evm'):
			from .Measurement_.Evm import Evm
			self._evm = Evm(self._core, self._base)
		return self._evm

	@property
	def ffError(self):
		"""ffError commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ffError'):
			from .Measurement_.FfError import FfError
			self._ffError = FfError(self._core, self._base)
		return self._ffError

	@property
	def fdeviation(self):
		"""fdeviation commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_fdeviation'):
			from .Measurement_.Fdeviation import Fdeviation
			self._fdeviation = Fdeviation(self._core, self._base)
		return self._fdeviation

	@property
	def fdError(self):
		"""fdError commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_fdError'):
			from .Measurement_.FdError import FdError
			self._fdError = FdError(self._core, self._base)
		return self._fdError

	@property
	def merror(self):
		"""merror commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_merror'):
			from .Measurement_.Merror import Merror
			self._merror = Merror(self._core, self._base)
		return self._merror

	@property
	def ptFive(self):
		"""ptFive commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ptFive'):
			from .Measurement_.PtFive import PtFive
			self._ptFive = PtFive(self._core, self._base)
		return self._ptFive

	@property
	def rfCarrier(self):
		"""rfCarrier commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfCarrier'):
			from .Measurement_.RfCarrier import RfCarrier
			self._rfCarrier = RfCarrier(self._core, self._base)
		return self._rfCarrier

	@property
	def sdistribute(self):
		"""sdistribute commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_sdistribute'):
			from .Measurement_.Sdistribute import Sdistribute
			self._sdistribute = Sdistribute(self._core, self._base)
		return self._sdistribute

	@property
	def spectrum(self):
		"""spectrum commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_spectrum'):
			from .Measurement_.Spectrum import Spectrum
			self._spectrum = Spectrum(self._core, self._base)
		return self._spectrum

	def stop(self) -> None:
		"""SCPI: STOP:VSE:MEASurement<Instance> \n
		Snippet: driver.vse.measurement.stop() \n
		Pauses the measurement. \n
		"""
		self._core.io.write(f'STOP:VSE:MEASurement<Instance>')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:VSE:MEASurement<Instance> \n
		Snippet: driver.vse.measurement.stop_with_opc() \n
		Pauses the measurement. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:VSE:MEASurement<Instance>')

	def abort(self) -> None:
		"""SCPI: ABORt:VSE:MEASurement<Instance> \n
		Snippet: driver.vse.measurement.abort() \n
		Stops the measurement. \n
		"""
		self._core.io.write(f'ABORt:VSE:MEASurement<Instance>')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:VSE:MEASurement<Instance> \n
		Snippet: driver.vse.measurement.abort_with_opc() \n
		Stops the measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:VSE:MEASurement<Instance>')

	def clone(self) -> 'Measurement':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Measurement(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Status:
	"""Status commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("status", core, parent)

	def get_bits(self) -> List[str]:
		"""SCPI: SYSTem:HELP:STATus:BITS \n
		Snippet: value: List[str] = driver.system.help.status.get_bits() \n
		No command help available \n
			:return: bits: No help available
		"""
		response = self._core.io.query_str('SYSTem:HELP:STATus:BITS?')
		return Conversions.str_to_str_list(response)

	def get_register(self) -> List[str]:
		"""SCPI: SYSTem:HELP:STATus[:REGister] \n
		Snippet: value: List[str] = driver.system.help.status.get_register() \n
		No command help available \n
			:return: register: No help available
		"""
		response = self._core.io.query_str('SYSTem:HELP:STATus:REGister?')
		return Conversions.str_to_str_list(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AudioOutput:
	"""AudioOutput commands group definition. 5 total commands, 4 Sub-groups, 1 group commands
	Repeated Capability: AudioOutput, default value after init: AudioOutput.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("audioOutput", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_audioOutput_get', 'repcap_audioOutput_set', repcap.AudioOutput.Nr1)

	def repcap_audioOutput_set(self, enum_value: repcap.AudioOutput) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AudioOutput.Default
		Default value after init: AudioOutput.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_audioOutput_get(self) -> repcap.AudioOutput:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .AudioOutput_.Level import Level
			self._level = Level(self._core, self._base)
		return self._level

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .AudioOutput_.Enable import Enable
			self._enable = Enable(self._core, self._base)
		return self._enable

	@property
	def first(self):
		"""first commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_first'):
			from .AudioOutput_.First import First
			self._first = First(self._core, self._base)
		return self._first

	@property
	def second(self):
		"""second commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_second'):
			from .AudioOutput_.Second import Second
			self._second = Second(self._core, self._base)
		return self._second

	def set(self, af_out_source: enums.SignalSource, audioOutput=repcap.AudioOutput.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:AOUT<nr> \n
		Snippet: driver.source.afRf.generator.audioOutput.set(af_out_source = enums.SignalSource.AFI1, audioOutput = repcap.AudioOutput.Default) \n
		Selects an audio signal source for an AF OUT connector. \n
			:param af_out_source: GEN1 | GEN2 | AFI1 | AFI2 | SPIL | SPIR GEN1 AF1 OUT source: Audio generator 1 AFI1 AF1 OUT source: AF1 IN SPIL AF1 OUT source: SPDIF IN, left channel GEN2 AF2 OUT source: Audio generator 2 AFI2 AF2 OUT source: AF2 IN SPIR AF2 OUT source: SPDIF IN, right channel
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')"""
		param = Conversions.enum_scalar_to_str(af_out_source, enums.SignalSource)
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:AOUT{audioOutput_cmd_val} {param}')

	# noinspection PyTypeChecker
	def get(self, audioOutput=repcap.AudioOutput.Default) -> enums.SignalSource:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:AOUT<nr> \n
		Snippet: value: enums.SignalSource = driver.source.afRf.generator.audioOutput.get(audioOutput = repcap.AudioOutput.Default) \n
		Selects an audio signal source for an AF OUT connector. \n
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')
			:return: af_out_source: GEN1 | GEN2 | AFI1 | AFI2 | SPIL | SPIR GEN1 AF1 OUT source: Audio generator 1 AFI1 AF1 OUT source: AF1 IN SPIL AF1 OUT source: SPDIF IN, left channel GEN2 AF2 OUT source: Audio generator 2 AFI2 AF2 OUT source: AF2 IN SPIR AF2 OUT source: SPDIF IN, right channel"""
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:AOUT{audioOutput_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.SignalSource)

	def clone(self) -> 'AudioOutput':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AudioOutput(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RecallState:
	"""RecallState commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("recallState", core, parent)

	def set(self, num: float) -> None:
		"""SCPI: *RCL \n
		Snippet: driver.recallState.set(num = 1.0) \n
		Loads the instrument settings from an intermediate memory identified by the specified number. The instrument settings can
		be stored to this memory using the command *SAV with the associated number. To load instrument settings from a file to
		the memory, see method RsCma.MassMemory.Load.State.set. See also MMEMory:RCL. \n
			:param num: Range: 0 to 99
		"""
		param = Conversions.decimal_value_to_str(num)
		self._core.io.write(f'*RCL {param}')



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class All:
	"""All commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("all", core, parent)

	# noinspection PyTypeChecker
	def fetch(self) -> List[enums.ResourceState]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:POWer:STATe:ALL \n
		Snippet: value: List[enums.ResourceState] = driver.gprfMeasurement.power.state.all.fetch() \n
		Queries the main power measurement state and all substates. The substates provide additional information for the main
		state RUN. \n
			:return: meas_state: No help available"""
		response = self._core.io.query_str(f'FETCh:GPRF:MEASurement<Instance>:POWer:STATe:ALL?')
		return Conversions.str_to_list_enum(response, enums.ResourceState)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, sav_rcl_state_number: int, filename: str, msus: str = None) -> None:
		"""SCPI: MMEMory:STORe:STATe \n
		Snippet: driver.massMemory.store.state.set(sav_rcl_state_number = 1, filename = '1', msus = '1') \n
		Stores the instrument settings from the specified internal memory to the specified file. To store the current instrument
		settings to the memory, use *SAV <MemoryNumber> first. \n
			:param sav_rcl_state_number: No help available
			:param filename: No help available
			:param msus: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('sav_rcl_state_number', sav_rcl_state_number, DataType.Integer), ArgSingle('filename', filename, DataType.String), ArgSingle('msus', msus, DataType.String, True))
		self._core.io.write(f'MMEMory:STORe:STATe {param}'.rstrip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Xrt:
	"""Xrt commands group definition. 4 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("xrt", core, parent)

	@property
	def rfSettings(self):
		"""rfSettings commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_rfSettings'):
			from .Xrt_.RfSettings import RfSettings
			self._rfSettings = RfSettings(self._core, self._base)
		return self._rfSettings

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:XRT:ENABle \n
		Snippet: value: bool = driver.configure.vse.measurement.xrt.get_enable() \n
		No command help available \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:XRT:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:XRT:ENABle \n
		Snippet: driver.configure.vse.measurement.xrt.set_enable(enable = False) \n
		No command help available \n
			:param enable: No help available
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:XRT:ENABle {param}')

	def clone(self) -> 'Xrt':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Xrt(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfCarrier:
	"""RfCarrier commands group definition. 51 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfCarrier", core, parent)

	@property
	def freqError(self):
		"""freqError commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqError'):
			from .RfCarrier_.FreqError import FreqError
			self._freqError = FreqError(self._core, self._base)
		return self._freqError

	@property
	def frequency(self):
		"""frequency commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .RfCarrier_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def power(self):
		"""power commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .RfCarrier_.Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def current(self):
		"""current commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_current'):
			from .RfCarrier_.Current import Current
			self._current = Current(self._core, self._base)
		return self._current

	@property
	def average(self):
		"""average commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_average'):
			from .RfCarrier_.Average import Average
			self._average = Average(self._core, self._base)
		return self._average

	@property
	def minimum(self):
		"""minimum commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_minimum'):
			from .RfCarrier_.Minimum import Minimum
			self._minimum = Minimum(self._core, self._base)
		return self._minimum

	@property
	def maximum(self):
		"""maximum commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_maximum'):
			from .RfCarrier_.Maximum import Maximum
			self._maximum = Maximum(self._core, self._base)
		return self._maximum

	@property
	def deviation(self):
		"""deviation commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_deviation'):
			from .RfCarrier_.Deviation import Deviation
			self._deviation = Deviation(self._core, self._base)
		return self._deviation

	def clone(self) -> 'RfCarrier':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RfCarrier(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ilevel:
	"""Ilevel commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ilevel", core, parent)

	def set(self, ilevel: List[float], internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:ILEVel \n
		Snippet: driver.source.afRf.generator.internalGenerator.multiTone.ilevel.set(ilevel = [1.1, 2.2, 3.3], internalGen = repcap.InternalGen.Default) \n
		Configures the levels of all tones of a multitone signal for edit mode INDividual. In edit mode TOTal, you can only query
		the levels, but not configure them. \n
			:param ilevel: Comma-separated list of up to 20 levels, for tone 1 to tone 20 You can specify fewer than 20 values to configure only the beginning of the tone list.
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.list_to_csv_str(ilevel)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:ILEVel {param}')

	def get(self, internalGen=repcap.InternalGen.Default) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:ILEVel \n
		Snippet: value: List[float] = driver.source.afRf.generator.internalGenerator.multiTone.ilevel.get(internalGen = repcap.InternalGen.Default) \n
		Configures the levels of all tones of a multitone signal for edit mode INDividual. In edit mode TOTal, you can only query
		the levels, but not configure them. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: ilevel: Comma-separated list of up to 20 levels, for tone 1 to tone 20 You can specify fewer than 20 values to configure only the beginning of the tone list."""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_bin_or_ascii_float_list(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:ILEVel?')
		return response



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bandwidth:
	"""Bandwidth commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bandwidth", core, parent)

	def set(self, bandpass_bw: float, standard: enums.Standard = None) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:FILTer:BANDpass:BWIDth \n
		Snippet: driver.configure.vse.measurement.iqRecorder.filterPy.bandpass.bandwidth.set(bandpass_bw = 1.0, standard = enums.Standard.CUSTom) \n
		Sets or queries the bandwidth of the bandpass filter and the related digital standard. \n
			:param bandpass_bw: Range: 1000 Hz to 40 MHz, Unit: Hz
			:param standard: DMR | NXDN | P25 | TETRa | LTE | UDEFined
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('bandpass_bw', bandpass_bw, DataType.Float), ArgSingle('standard', standard, DataType.Enum, True))
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:FILTer:BANDpass:BWIDth {param}'.rstrip())

	def get(self) -> float:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:FILTer:BANDpass:BWIDth \n
		Snippet: value: float = driver.configure.vse.measurement.iqRecorder.filterPy.bandpass.bandwidth.get() \n
		Sets or queries the bandwidth of the bandpass filter and the related digital standard. \n
			:return: bandpass_bw: Range: 1000 Hz to 40 MHz, Unit: Hz"""
		response = self._core.io.query_str(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:FILTer:BANDpass:BWIDth?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rrc:
	"""Rrc commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rrc", core, parent)

	def get_roff_factor(self) -> float:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:DMR:FILTer:RRC:ROFFfactor \n
		Snippet: value: float = driver.configure.vse.measurement.dmr.filterPy.rrc.get_roff_factor() \n
		Queries the roll-off factor of the filter used for pulse shaping for DMR. \n
			:return: rolloff_factor: Range: 0.2 to 0.2
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:DMR:FILTer:RRC:ROFFfactor?')
		return Conversions.str_to_float(response)



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Applications:
	"""Applications commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("applications", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: SENSe:DISPlay:APPLications:CATalog \n
		Snippet: value: List[str] = driver.sense.display.applications.get_catalog() \n
		Queries a list of all applications available in the current scenario. \n
			:return: app_list: Comma-separated list of strings, each string indicating one application, for example 'Generator' or 'Analyzer'
		"""
		response = self._core.io.query_str('SENSe:DISPlay:APPLications:CATalog?')
		return Conversions.str_to_str_list(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SearchRoutines:
	"""SearchRoutines commands group definition. 42 total commands, 8 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("searchRoutines", core, parent)

	@property
	def dialing(self):
		"""dialing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dialing'):
			from .SearchRoutines_.Dialing import Dialing
			self._dialing = Dialing(self._core, self._base)
		return self._dialing

	@property
	def rx(self):
		"""rx commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_rx'):
			from .SearchRoutines_.Rx import Rx
			self._rx = Rx(self._core, self._base)
		return self._rx

	@property
	def tx(self):
		"""tx commands group. 1 Sub-classes, 7 commands."""
		if not hasattr(self, '_tx'):
			from .SearchRoutines_.Tx import Tx
			self._tx = Tx(self._core, self._base)
		return self._tx

	@property
	def limit(self):
		"""limit commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_limit'):
			from .SearchRoutines_.Limit import Limit
			self._limit = Limit(self._core, self._base)
		return self._limit

	@property
	def rifBandwidth(self):
		"""rifBandwidth commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rifBandwidth'):
			from .SearchRoutines_.RifBandwidth import RifBandwidth
			self._rifBandwidth = RifBandwidth(self._core, self._base)
		return self._rifBandwidth

	@property
	def rsquelch(self):
		"""rsquelch commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_rsquelch'):
			from .SearchRoutines_.Rsquelch import Rsquelch
			self._rsquelch = Rsquelch(self._core, self._base)
		return self._rsquelch

	@property
	def ssnr(self):
		"""ssnr commands group. 0 Sub-classes, 7 commands."""
		if not hasattr(self, '_ssnr'):
			from .SearchRoutines_.Ssnr import Ssnr
			self._ssnr = Ssnr(self._core, self._base)
		return self._ssnr

	@property
	def tsensitivity(self):
		"""tsensitivity commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_tsensitivity'):
			from .SearchRoutines_.Tsensitivity import Tsensitivity
			self._tsensitivity = Tsensitivity(self._core, self._base)
		return self._tsensitivity

	def get_mrf_level(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:MRFLevel \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.get_mrf_level() \n
		Configures the maximum RF level for the signal generator. A too high value can damage your DUT. \n
			:return: max_level: Range: -130 dBm to -30 dBm, Unit: dBm
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:MRFLevel?')
		return Conversions.str_to_float(response)

	def set_mrf_level(self, max_level: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:MRFLevel \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.set_mrf_level(max_level = 1.0) \n
		Configures the maximum RF level for the signal generator. A too high value can damage your DUT. \n
			:param max_level: Range: -130 dBm to -30 dBm, Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(max_level)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:MRFLevel {param}')

	def get_sq_value(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SQValue \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.get_sq_value() \n
		Configures the target value for the audio signal quality. \n
			:return: target_par_val: Range: 1 dB to 46 dB, Unit: dB
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SQValue?')
		return Conversions.str_to_float(response)

	def set_sq_value(self, target_par_val: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SQValue \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.set_sq_value(target_par_val = 1.0) \n
		Configures the target value for the audio signal quality. \n
			:param target_par_val: Range: 1 dB to 46 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(target_par_val)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SQValue {param}')

	# noinspection PyTypeChecker
	def get_sq_type(self) -> enums.TargetParType:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SQTYpe \n
		Snippet: value: enums.TargetParType = driver.configure.afRf.measurement.searchRoutines.get_sq_type() \n
		Selects the type of audio signal quality to be measured. \n
			:return: target_par_type: SINad | SNRatio | SNNRatio | SNDNratio
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:SQTYpe?')
		return Conversions.str_to_scalar_enum(response, enums.TargetParType)

	def set_sq_type(self, target_par_type: enums.TargetParType) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:SQTYpe \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.set_sq_type(target_par_type = enums.TargetParType.SINad) \n
		Selects the type of audio signal quality to be measured. \n
			:param target_par_type: SINad | SNRatio | SNNRatio | SNDNratio
		"""
		param = Conversions.enum_scalar_to_str(target_par_type, enums.TargetParType)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:SQTYpe {param}')

	def get_stolerance(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:STOLerance \n
		Snippet: value: float = driver.configure.afRf.measurement.searchRoutines.get_stolerance() \n
		The maximum allowed deviation of the current signal quality from the average signal quality. \n
			:return: tolerance: Unit: dB
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:STOLerance?')
		return Conversions.str_to_float(response)

	def set_stolerance(self, tolerance: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:STOLerance \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.set_stolerance(tolerance = 1.0) \n
		The maximum allowed deviation of the current signal quality from the average signal quality. \n
			:param tolerance: Unit: dB
		"""
		param = Conversions.decimal_value_to_str(tolerance)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:STOLerance {param}')

	# noinspection PyTypeChecker
	def get_path(self) -> enums.SearchRoutinePath:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:PATH \n
		Snippet: value: enums.SearchRoutinePath = driver.configure.afRf.measurement.searchRoutines.get_path() \n
		Configures the path from where the test instrument receives the audio input by the connector or by 'VoIP'. \n
			:return: path: AFI1 | AFI2 | VOIP
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:PATH?')
		return Conversions.str_to_scalar_enum(response, enums.SearchRoutinePath)

	def set_path(self, path: enums.SearchRoutinePath) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:PATH \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.set_path(path = enums.SearchRoutinePath.AFI1) \n
		Configures the path from where the test instrument receives the audio input by the connector or by 'VoIP'. \n
			:param path: AFI1 | AFI2 | VOIP
		"""
		param = Conversions.enum_scalar_to_str(path, enums.SearchRoutinePath)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:PATH {param}')

	def clone(self) -> 'SearchRoutines':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SearchRoutines(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SnRatio:
	"""SnRatio commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("snRatio", core, parent)

	# noinspection PyTypeChecker
	class SnRatioStruct(StructBase):
		"""Structure for setting input parameters. Contains optional setting parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower limit Range: 1 dB to 46 dB, Unit: dB
			- Upper: float: Optional setting parameter. Upper limit Range: 1 dB to 46 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def set(self, structure: SnRatioStruct, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:AIN<Nr>:SNRatio \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.audioInput.snRatio.set(value = [PROPERTY_STRUCT_NAME](), audioInput = repcap.AudioInput.Default) \n
		Configures limits for all SNR results, measured via an AF input path. SNR results include S/N, (S+N) /N and (S+N+D) /N. \n
			:param structure: for set value, see the help for SnRatioStruct structure arguments.
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write_struct(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:AIN{audioInput_cmd_val}:SNRatio', structure)

	def get(self, audioInput=repcap.AudioInput.Default) -> SnRatioStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:AIN<Nr>:SNRatio \n
		Snippet: value: SnRatioStruct = driver.configure.afRf.measurement.multiEval.limit.audioInput.snRatio.get(audioInput = repcap.AudioInput.Default) \n
		Configures limits for all SNR results, measured via an AF input path. SNR results include S/N, (S+N) /N and (S+N+D) /N. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for SnRatioStruct structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:AIN{audioInput_cmd_val}:SNRatio?', self.__class__.SnRatioStruct())



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Measurement:
	"""Measurement commands group definition. 625 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("measurement", core, parent)

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 3 commands."""
		if not hasattr(self, '_data'):
			from .Measurement_.Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	@property
	def multiEval(self):
		"""multiEval commands group. 14 Sub-classes, 3 commands."""
		if not hasattr(self, '_multiEval'):
			from .Measurement_.MultiEval import MultiEval
			self._multiEval = MultiEval(self._core, self._base)
		return self._multiEval

	@property
	def searchRoutines(self):
		"""searchRoutines commands group. 6 Sub-classes, 3 commands."""
		if not hasattr(self, '_searchRoutines'):
			from .Measurement_.SearchRoutines import SearchRoutines
			self._searchRoutines = SearchRoutines(self._core, self._base)
		return self._searchRoutines

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Measurement_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	def clone(self) -> 'Measurement':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Measurement(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spdif:
	"""Spdif commands group definition. 26 total commands, 3 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spdif", core, parent)

	@property
	def level(self):
		"""level commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_level'):
			from .Spdif_.Level import Level
			self._level = Level(self._core, self._base)
		return self._level

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Spdif_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def filterPy(self):
		"""filterPy commands group. 2 Sub-classes, 6 commands."""
		if not hasattr(self, '_filterPy'):
			from .Spdif_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Test_Left: bool: OFF | ON Switches the left channel off or on
			- Test_Right: bool: OFF | ON Switches the right channel off or on"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Test_Left'),
			ArgStruct.scalar_bool('Test_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Test_Left: bool = None
			self.Test_Right: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:ENABle \n
		Snippet: value: EnableStruct = driver.configure.afRf.measurement.spdif.get_enable() \n
		Enables or disables the channels of the SPDIF IN connector. \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:ENABle \n
		Snippet: driver.configure.afRf.measurement.spdif.set_enable(value = EnableStruct()) \n
		Enables or disables the channels of the SPDIF IN connector. \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:ENABle', value)

	# noinspection PyTypeChecker
	class GcouplingStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Coupling_Left: enums.GeneratorCoupling: OFF | GEN1 | GEN3 OFF No coupling of left channel GENn Left channel coupled to audio generator n
			- Coupling_Right: enums.GeneratorCoupling: OFF | GEN2 | GEN4 OFF No coupling of right channel GENn Right channel coupled to audio generator n"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Coupling_Left', enums.GeneratorCoupling),
			ArgStruct.scalar_enum('Coupling_Right', enums.GeneratorCoupling)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Coupling_Left: enums.GeneratorCoupling = None
			self.Coupling_Right: enums.GeneratorCoupling = None

	# noinspection PyTypeChecker
	def get_gcoupling(self) -> GcouplingStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:GCOupling \n
		Snippet: value: GcouplingStruct = driver.configure.afRf.measurement.spdif.get_gcoupling() \n
		Couples the channels of the SPDIF IN connector to an internal signal generator. The combinations GEN1+GEN4 and GEN3+GEN2
		are not allowed. \n
			:return: structure: for return value, see the help for GcouplingStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:GCOupling?', self.__class__.GcouplingStruct())

	def set_gcoupling(self, value: GcouplingStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:GCOupling \n
		Snippet: driver.configure.afRf.measurement.spdif.set_gcoupling(value = GcouplingStruct()) \n
		Couples the channels of the SPDIF IN connector to an internal signal generator. The combinations GEN1+GEN4 and GEN3+GEN2
		are not allowed. \n
			:param value: see the help for GcouplingStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:GCOupling', value)

	# noinspection PyTypeChecker
	class TmodeStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Tone_Mode_Left: enums.ToneMode: No parameter help available
			- Tone_Mode_Right: enums.DigitalToneMode: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Tone_Mode_Left', enums.ToneMode),
			ArgStruct.scalar_enum('Tone_Mode_Right', enums.DigitalToneMode)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Tone_Mode_Left: enums.ToneMode = None
			self.Tone_Mode_Right: enums.DigitalToneMode = None

	# noinspection PyTypeChecker
	def get_tmode(self) -> TmodeStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:TMODe \n
		Snippet: value: TmodeStruct = driver.configure.afRf.measurement.spdif.get_tmode() \n
		No command help available \n
			:return: structure: for return value, see the help for TmodeStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:TMODe?', self.__class__.TmodeStruct())

	def set_tmode(self, value: TmodeStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:TMODe \n
		Snippet: driver.configure.afRf.measurement.spdif.set_tmode(value = TmodeStruct()) \n
		No command help available \n
			:param value: see the help for TmodeStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:TMODe', value)

	def clone(self) -> 'Spdif':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Spdif(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Forward:
	"""Forward commands group definition. 6 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("forward", core, parent)

	@property
	def value(self):
		"""value commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_value'):
			from .Forward_.Value import Value
			self._value = Value(self._core, self._base)
		return self._value

	@property
	def limit(self):
		"""limit commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_limit'):
			from .Forward_.Limit import Limit
			self._limit = Limit(self._core, self._base)
		return self._limit

	def clone(self) -> 'Forward':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Forward(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Use:
	"""Use commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("use", core, parent)

	def set(self) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:USE \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.use.set() \n
			INTRO_CMD_HELP: Applies the search results to the RF settings: \n
			- The center frequency of the RF analyzer is set to the counted frequency.
			- The expected power is set to the measured power plus 10 dB. \n
		"""
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:USE')

	def set_with_opc(self) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:USE \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.use.set_with_opc() \n
			INTRO_CMD_HELP: Applies the search results to the RF settings: \n
			- The center frequency of the RF analyzer is set to the counted frequency.
			- The expected power is set to the measured power plus 10 dB. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:USE')



from typing import List

from .Internal.Core import Core
from .Internal.InstrumentErrors import RsInstrException
from .Internal.CommandsGroup import CommandsGroup
from .Internal.VisaSession import VisaSession
from . import repcap
from .Internal.RepeatedCapability import RepeatedCapability


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RsCma:
	"""2069 total commands, 21 Sub-groups, 0 group commands"""
	_driver_options = "SupportedInstrModels = CMA180, SupportedIdnPatterns = CMA, SimulationIdnString = 'Rohde&Schwarz,CMA180,100001,1.7.10.0024'"

	def __init__(self, resource_name: str, id_query: bool = True, reset: bool = False, options: str = None, direct_session: object = None):
		"""Initializes new RsCma session. \n
		Parameter options tokens examples:
			- 'Simulate=True' - starts the session in simulation mode. Default: False
			- 'SelectVisa=socket' - uses no VISA implementation for socket connections - you do not need any VISA-C installation
			- 'SelectVisa=rs' - forces usage of RohdeSchwarz Visa
			- 'SelectVisa=ni' - forces usage of National Instruments Visa
			- 'QueryInstrumentStatus = False' - same as driver.utilities.instrument_status_checking = False
			- 'DriverSetup=(WriteDelay = 20, ReadDelay = 5)' - Introduces delay of 20ms before each write and 5ms before each read
			- 'DriverSetup=(OpcWaitMode = OpcQuery)' - mode for all the opc-synchronised write/reads. Other modes: StbPolling, StbPollingSlow, StbPollingSuperSlow
			- 'DriverSetup=(AddTermCharToWriteBinBLock = True)' - Adds one additional LF to the end of the binary data (some instruments require that)
			- 'DriverSetup=(AssureWriteWithTermChar = True)' - Makes sure each command/query is terminated with termination character. Default: Interface dependent
			- 'DriverSetup=(TerminationCharacter = 'x')' - Sets the termination character for reading. Default: '<LF>' (LineFeed)
			- 'DriverSetup=(IoSegmentSize = 10E3)' - Maximum size of one write/read segment. If transferred data is bigger, it is split to more segments
			- 'DriverSetup=(OpcTimeout = 10000)' - same as driver.utilities.opc_timeout = 10000
			- 'DriverSetup=(VisaTimeout = 5000)' - same as driver.utilities.visa_timeout = 5000
			- 'DriverSetup=(ViClearExeMode = 255)' - Binary combination where 1 means performing viClear() on a certain interface as the very first command in init
			- 'DriverSetup=(OpcQueryAfterWrite = True)' - same as driver.utilities.opc_query_after_write = True
		:param resource_name: VISA resource name, e.g. 'TCPIP::192.168.2.1::INSTR'
		:param id_query: if True: the instrument's model name is verified against the models supported by the driver and eventually throws an exception.
		:param reset: Resets the instrument (sends *RST command) and clears its status sybsystem
		:param options: string tokens alternating the driver settings.
		:param direct_session: Another driver object or pyVisa object to reuse the session instead of opening a new session."""
		self._core = Core(resource_name, id_query, reset, RsCma._driver_options, options, direct_session)
		self._core.driver_version = '1.7.10.0024'
		self._options = options
		self._add_all_global_repcaps()
		self._custom_properties_init()
		# noinspection PyTypeChecker
		self._base = CommandsGroup("ROOT", self._core, None)

	@classmethod
	def from_existing_session(cls, session: object, options: str = None) -> 'RsCma':
		"""Creates a new RsCma object with the entered 'session' reused. \n
		:param session: can be an another driver or a direct pyvisa session.
		:param options: string tokens alternating the driver settings."""
		# noinspection PyTypeChecker
		return cls(None, False, False, options, session)

	def __str__(self) -> str:
		if self._core.io:
			return f"RsCma session '{self._core.io.resource_name}'"
		else:
			return f"RsCma with session closed"

	@staticmethod
	def assert_minimum_version(min_version: str) -> None:
		"""Asserts that the driver version fulfills the minimum required version you have entered.
		This way you make sure your installed driver is of the entered version or newer."""
		min_version_list = min_version.split('.')
		curr_version_list = '1.7.10.0024'.split('.')
		count_min = len(min_version_list)
		count_curr = len(curr_version_list)
		count = count_min if count_min < count_curr else count_curr
		for i in range(count):
			minimum = int(min_version_list[i])
			curr = int(curr_version_list[i])
			if curr > minimum:
				break
			if curr < minimum:
				raise RsInstrException(f"Assertion for minimum RsCma version failed. Current version: '1.7.10.0024', minimum required version: '{min_version}'")
				
	@staticmethod
	def list_resources(expression: str = '?*::INSTR', visa_select: str = None) -> List[str]:
		"""Finds all the resources defined by the expression
			- '?*' - matches all the available instruments
			- 'USB::?*' - matches all the USB instruments
			- "TCPIP::192?*' - matches all the LAN instruments with the IP address starting with 192
		:param expression: see the examples in the function
		:param visa_select: optional parameter selecting a specific VISA. Examples: '@ni', '@rs'
		"""
		rm = VisaSession.get_resource_manager(visa_select)
		resources = rm.list_resources(expression)
		rm.close()
		# noinspection PyTypeChecker
		return resources

	def close(self) -> None:
		"""Closes the active RsCma session."""
		self._core.io.close()

	def get_session_handle(self) -> object:
		"""Returns the underlying session handle."""
		return self._core.get_session_handle()

	def _add_all_global_repcaps(self) -> None:
		"""Adds all the repcaps defined as global to the instrument's global repcaps dictionary."""
		self._core.io.add_global_repcap('<Instance>', RepeatedCapability("ROOT", 'repcap_instance_get', 'repcap_instance_set', repcap.Instance.Inst1))

	def repcap_instance_get(self) -> repcap.Instance:
		"""Returns Global Repeated capability Instance \n
		Selects the instrument"""
		return self._core.io.get_global_repcap_value('<Instance>')

	def repcap_instance_set(self, value: repcap.Instance) -> None:
		"""Sets Global Repeated capability Instance \n
		Selects the instrument
		Default value after init: Instance.Inst1"""
		self._core.io.set_global_repcap_value('<Instance>', value)

	def _custom_properties_init(self):
		"""Adds all the interfaces that are custom for the driver."""
		from .CustomFiles.utilities import Utilities
		self.utilities = Utilities(self._core)
		from .CustomFiles.events import Events
		self.events = Events(self._core)
		from .CustomFiles.reliability import Reliability
		self.reliability = Reliability(self._core)

	@property
	def source(self):
		"""source commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_source'):
			from .Implementations.Source import Source
			self._source = Source(self._core, self._base)
		return self._source

	@property
	def configure(self):
		"""configure commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_configure'):
			from .Implementations.Configure import Configure
			self._configure = Configure(self._core, self._base)
		return self._configure

	@property
	def trigger(self):
		"""trigger commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_trigger'):
			from .Implementations.Trigger import Trigger
			self._trigger = Trigger(self._core, self._base)
		return self._trigger

	@property
	def afRf(self):
		"""afRf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_afRf'):
			from .Implementations.AfRf import AfRf
			self._afRf = AfRf(self._core, self._base)
		return self._afRf

	@property
	def display(self):
		"""display commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_display'):
			from .Implementations.Display import Display
			self._display = Display(self._core, self._base)
		return self._display

	@property
	def sense(self):
		"""sense commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_sense'):
			from .Implementations.Sense import Sense
			self._sense = Sense(self._core, self._base)
		return self._sense

	@property
	def calibration(self):
		"""calibration commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_calibration'):
			from .Implementations.Calibration import Calibration
			self._calibration = Calibration(self._core, self._base)
		return self._calibration

	@property
	def system(self):
		"""system commands group. 9 Sub-classes, 6 commands."""
		if not hasattr(self, '_system'):
			from .Implementations.System import System
			self._system = System(self._core, self._base)
		return self._system

	@property
	def firmwareUpdate(self):
		"""firmwareUpdate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_firmwareUpdate'):
			from .Implementations.FirmwareUpdate import FirmwareUpdate
			self._firmwareUpdate = FirmwareUpdate(self._core, self._base)
		return self._firmwareUpdate

	@property
	def gprfMeasurement(self):
		"""gprfMeasurement commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_gprfMeasurement'):
			from .Implementations.GprfMeasurement import GprfMeasurement
			self._gprfMeasurement = GprfMeasurement(self._core, self._base)
		return self._gprfMeasurement

	@property
	def saveState(self):
		"""saveState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_saveState'):
			from .Implementations.SaveState import SaveState
			self._saveState = SaveState(self._core, self._base)
		return self._saveState

	@property
	def recallState(self):
		"""recallState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_recallState'):
			from .Implementations.RecallState import RecallState
			self._recallState = RecallState(self._core, self._base)
		return self._recallState

	@property
	def massMemory(self):
		"""massMemory commands group. 6 Sub-classes, 7 commands."""
		if not hasattr(self, '_massMemory'):
			from .Implementations.MassMemory import MassMemory
			self._massMemory = MassMemory(self._core, self._base)
		return self._massMemory

	@property
	def hardCopy(self):
		"""hardCopy commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_hardCopy'):
			from .Implementations.HardCopy import HardCopy
			self._hardCopy = HardCopy(self._core, self._base)
		return self._hardCopy

	@property
	def status(self):
		"""status commands group. 7 Sub-classes, 1 commands."""
		if not hasattr(self, '_status'):
			from .Implementations.Status import Status
			self._status = Status(self._core, self._base)
		return self._status

	@property
	def instrument(self):
		"""instrument commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_instrument'):
			from .Implementations.Instrument import Instrument
			self._instrument = Instrument(self._core, self._base)
		return self._instrument

	@property
	def formatPy(self):
		"""formatPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_formatPy'):
			from .Implementations.FormatPy import FormatPy
			self._formatPy = FormatPy(self._core, self._base)
		return self._formatPy

	@property
	def unit(self):
		"""unit commands group. 0 Sub-classes, 14 commands."""
		if not hasattr(self, '_unit'):
			from .Implementations.Unit import Unit
			self._unit = Unit(self._core, self._base)
		return self._unit

	@property
	def trace(self):
		"""trace commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_trace'):
			from .Implementations.Trace import Trace
			self._trace = Trace(self._core, self._base)
		return self._trace

	@property
	def vse(self):
		"""vse commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_vse'):
			from .Implementations.Vse import Vse
			self._vse = Vse(self._core, self._base)
		return self._vse

	@property
	def init(self):
		"""init commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_init'):
			from .Implementations.Init import Init
			self._init = Init(self._core, self._base)
		return self._init

	def clone(self) -> 'RsCma':
		"""Creates a deep copy of the RsCma object. Also copies:
			- All the existing Global repeated capability values
			- All the default group repeated capabilities setting \n
		Does not check the *IDN? response, and does not perform Reset.
		After cloning, you can set all the repeated capabilities settings independentely from the original group.
		Calling close() on the new object does not close the original VISA session"""
		cloned = RsCma.from_existing_session(self.get_session_handle(), self._options)
		self._base.synchronize_repcaps(cloned)
		cloned.repcap_instance_set(self.repcap_instance_get())
		return cloned

	def restore_all_repcaps_to_default(self) -> None:
		"""Sets all the Group and Global repcaps to their initial values"""
		self._base.restore_repcaps()
		self.repcap_instance_set(repcap.Instance.Inst1)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Temperature:
	"""Temperature commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("temperature", core, parent)

	@property
	def exceeded(self):
		"""exceeded commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_exceeded'):
			from .Temperature_.Exceeded import Exceeded
			self._exceeded = Exceeded(self._core, self._base)
		return self._exceeded

	def get_environment(self) -> float:
		"""SCPI: SENSe:BASE:TEMPerature:ENVironment \n
		Snippet: value: float = driver.sense.base.temperature.get_environment() \n
		No command help available \n
			:return: temperature: No help available
		"""
		response = self._core.io.query_str('SENSe:BASE:TEMPerature:ENVironment?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Temperature':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Temperature(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Madeviation:
	"""Madeviation commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("madeviation", core, parent)

	def set(self, max_audio_deviation: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:FMSTereo:MADeviation \n
		Snippet: driver.source.afRf.generator.modulator.fmStereo.madeviation.set(max_audio_deviation = 1.0) \n
		Specifies the maximum frequency deviation for the audio signal component of a generated FM stereo multiplex signal. The
		allowed range depends on the frequency deviation of the other signal components. The total deviation of the multiplex
		signal must not exceed 100 kHz. A query returns <MaxAudioDeviation>, <Ratio>. \n
			:param max_audio_deviation: Maximum audio deviation in Hz Range: 0 Hz to 100 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(max_audio_deviation)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:MODulator:FMSTereo:MADeviation {param}')

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Max_Audio_Deviation: float: Maximum audio deviation in Hz Range: 0 Hz to 100 kHz, Unit: Hz
			- Ratio: float: Maximum audio deviation as percentage of the multiplex deviation Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_float('Max_Audio_Deviation'),
			ArgStruct.scalar_float('Ratio')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Max_Audio_Deviation: float = None
			self.Ratio: float = None

	def get(self) -> GetStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:FMSTereo:MADeviation \n
		Snippet: value: GetStruct = driver.source.afRf.generator.modulator.fmStereo.madeviation.get() \n
		Specifies the maximum frequency deviation for the audio signal component of a generated FM stereo multiplex signal. The
		allowed range depends on the frequency deviation of the other signal components. The total deviation of the multiplex
		signal must not exceed 100 kHz. A query returns <MaxAudioDeviation>, <Ratio>. \n
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce:AFRF:GENerator<Instance>:MODulator:FMSTereo:MADeviation?', self.__class__.GetStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	# noinspection PyTypeChecker
	def get_source(self) -> enums.RefFreqSource:
		"""SCPI: SYSTem:BASE:REFerence:FREQuency:SOURce \n
		Snippet: value: enums.RefFreqSource = driver.system.base.reference.frequency.get_source() \n
		Selects whether an internal or external reference frequency source is used. \n
			:return: source: INTernal | EXTernal
		"""
		response = self._core.io.query_str_with_opc('SYSTem:BASE:REFerence:FREQuency:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.RefFreqSource)

	def set_source(self, source: enums.RefFreqSource) -> None:
		"""SCPI: SYSTem:BASE:REFerence:FREQuency:SOURce \n
		Snippet: driver.system.base.reference.frequency.set_source(source = enums.RefFreqSource.EXTernal) \n
		Selects whether an internal or external reference frequency source is used. \n
			:param source: INTernal | EXTernal
		"""
		param = Conversions.enum_scalar_to_str(source, enums.RefFreqSource)
		self._core.io.write_with_opc(f'SYSTem:BASE:REFerence:FREQuency:SOURce {param}')
